@@ -2,209 +2,217 @@ use super::*;
 
 impl AddAssign<PointSize> for PointStyle {
     fn add_assign(&mut self, rhs: PointSize) {
-        self.point_size = Some(rhs.value);
+        self.point_size = Some(rhs);
     }
 }
 
 impl AddAssign<&PointSize> for PointStyle {
     fn add_assign(&mut self, rhs: &PointSize) {
-        self.point_size = Some(rhs.value.clone());
+        self.point_size = Some(rhs.clone());
     }
 }
 
 impl AddAssign<PointSize> for StyleContext {
     fn add_assign(&mut self, rhs: PointSize) {
-        self.point_size = Some(rhs.value);
+        self.point_size = Some(rhs);
     }
 }
 
 impl AddAssign<&PointSize> for StyleContext {
     fn add_assign(&mut self, rhs: &PointSize) {
-        self.point_size = Some(rhs.value);
+        self.point_size = Some(rhs.clone());
     }
 }
+
 impl AddAssign<PointColor> for PointStyle {
     fn add_assign(&mut self, rhs: PointColor) {
-        self.point_color = Some(rhs.value);
+        self.point_color = Some(rhs);
     }
 }
 
 impl AddAssign<&PointColor> for PointStyle {
     fn add_assign(&mut self, rhs: &PointColor) {
-        self.point_color = Some(rhs.value.clone());
+        self.point_color = Some(rhs.clone());
     }
 }
 
 impl AddAssign<PointColor> for StyleContext {
     fn add_assign(&mut self, rhs: PointColor) {
-        self.point_color = Some(rhs.value);
+        self.point_color = Some(rhs);
     }
 }
 
 impl AddAssign<&PointColor> for StyleContext {
     fn add_assign(&mut self, rhs: &PointColor) {
-        self.point_color = Some(rhs.value);
+        self.point_color = Some(rhs.clone());
     }
 }
+
 impl AddAssign<CircleWidth> for CircleStyle {
     fn add_assign(&mut self, rhs: CircleWidth) {
-        self.circle_width = Some(rhs.value);
+        self.circle_width = Some(rhs);
     }
 }
 
 impl AddAssign<&CircleWidth> for CircleStyle {
     fn add_assign(&mut self, rhs: &CircleWidth) {
-        self.circle_width = Some(rhs.value.clone());
+        self.circle_width = Some(rhs.clone());
     }
 }
 
 impl AddAssign<CircleWidth> for StyleContext {
     fn add_assign(&mut self, rhs: CircleWidth) {
-        self.circle_width = Some(rhs.value);
+        self.circle_width = Some(rhs);
     }
 }
 
 impl AddAssign<&CircleWidth> for StyleContext {
     fn add_assign(&mut self, rhs: &CircleWidth) {
-        self.circle_width = Some(rhs.value);
+        self.circle_width = Some(rhs.clone());
     }
 }
+
 impl AddAssign<CircleColor> for CircleStyle {
     fn add_assign(&mut self, rhs: CircleColor) {
-        self.circle_color = Some(rhs.value);
+        self.circle_color = Some(rhs);
     }
 }
 
 impl AddAssign<&CircleColor> for CircleStyle {
     fn add_assign(&mut self, rhs: &CircleColor) {
-        self.circle_color = Some(rhs.value.clone());
+        self.circle_color = Some(rhs.clone());
     }
 }
 
 impl AddAssign<CircleColor> for StyleContext {
     fn add_assign(&mut self, rhs: CircleColor) {
-        self.circle_color = Some(rhs.value);
+        self.circle_color = Some(rhs);
     }
 }
 
 impl AddAssign<&CircleColor> for StyleContext {
     fn add_assign(&mut self, rhs: &CircleColor) {
-        self.circle_color = Some(rhs.value);
+        self.circle_color = Some(rhs.clone());
     }
 }
+
 impl AddAssign<DiskFillColor> for DiskStyle {
     fn add_assign(&mut self, rhs: DiskFillColor) {
-        self.disk_fill_color = Some(rhs.value);
+        self.disk_fill_color = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskFillColor> for DiskStyle {
     fn add_assign(&mut self, rhs: &DiskFillColor) {
-        self.disk_fill_color = Some(rhs.value.clone());
+        self.disk_fill_color = Some(rhs.clone());
     }
 }
 
 impl AddAssign<DiskFillColor> for StyleContext {
     fn add_assign(&mut self, rhs: DiskFillColor) {
-        self.disk_fill_color = Some(rhs.value);
+        self.disk_fill_color = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskFillColor> for StyleContext {
     fn add_assign(&mut self, rhs: &DiskFillColor) {
-        self.disk_fill_color = Some(rhs.value);
+        self.disk_fill_color = Some(rhs.clone());
     }
 }
+
 impl AddAssign<DiskEdgeWidth> for DiskStyle {
     fn add_assign(&mut self, rhs: DiskEdgeWidth) {
-        self.disk_edge_width = Some(rhs.value);
+        self.disk_edge_width = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskEdgeWidth> for DiskStyle {
     fn add_assign(&mut self, rhs: &DiskEdgeWidth) {
-        self.disk_edge_width = Some(rhs.value.clone());
+        self.disk_edge_width = Some(rhs.clone());
     }
 }
 
 impl AddAssign<DiskEdgeWidth> for StyleContext {
     fn add_assign(&mut self, rhs: DiskEdgeWidth) {
-        self.disk_edge_width = Some(rhs.value);
+        self.disk_edge_width = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskEdgeWidth> for StyleContext {
     fn add_assign(&mut self, rhs: &DiskEdgeWidth) {
-        self.disk_edge_width = Some(rhs.value);
+        self.disk_edge_width = Some(rhs.clone());
     }
 }
+
 impl AddAssign<DiskEdgeColor> for DiskStyle {
     fn add_assign(&mut self, rhs: DiskEdgeColor) {
-        self.disk_edge_color = Some(rhs.value);
+        self.disk_edge_color = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskEdgeColor> for DiskStyle {
     fn add_assign(&mut self, rhs: &DiskEdgeColor) {
-        self.disk_edge_color = Some(rhs.value.clone());
+        self.disk_edge_color = Some(rhs.clone());
     }
 }
 
 impl AddAssign<DiskEdgeColor> for StyleContext {
     fn add_assign(&mut self, rhs: DiskEdgeColor) {
-        self.disk_edge_color = Some(rhs.value);
+        self.disk_edge_color = Some(rhs);
     }
 }
 
 impl AddAssign<&DiskEdgeColor> for StyleContext {
     fn add_assign(&mut self, rhs: &DiskEdgeColor) {
-        self.disk_edge_color = Some(rhs.value);
+        self.disk_edge_color = Some(rhs.clone());
     }
 }
+
 impl AddAssign<LineWidth> for LineStyle {
     fn add_assign(&mut self, rhs: LineWidth) {
-        self.line_width = Some(rhs.value);
+        self.line_width = Some(rhs);
     }
 }
 
 impl AddAssign<&LineWidth> for LineStyle {
     fn add_assign(&mut self, rhs: &LineWidth) {
-        self.line_width = Some(rhs.value.clone());
+        self.line_width = Some(rhs.clone());
     }
 }
 
 impl AddAssign<LineWidth> for StyleContext {
     fn add_assign(&mut self, rhs: LineWidth) {
-        self.line_width = Some(rhs.value);
+        self.line_width = Some(rhs);
     }
 }
 
 impl AddAssign<&LineWidth> for StyleContext {
     fn add_assign(&mut self, rhs: &LineWidth) {
-        self.line_width = Some(rhs.value);
+        self.line_width = Some(rhs.clone());
     }
 }
+
 impl AddAssign<LineColor> for LineStyle {
     fn add_assign(&mut self, rhs: LineColor) {
-        self.line_color = Some(rhs.value);
+        self.line_color = Some(rhs);
     }
 }
 
 impl AddAssign<&LineColor> for LineStyle {
     fn add_assign(&mut self, rhs: &LineColor) {
-        self.line_color = Some(rhs.value.clone());
+        self.line_color = Some(rhs.clone());
     }
 }
 
 impl AddAssign<LineColor> for StyleContext {
     fn add_assign(&mut self, rhs: LineColor) {
-        self.line_color = Some(rhs.value);
+        self.line_color = Some(rhs);
     }
 }
 
 impl AddAssign<&LineColor> for StyleContext {
     fn add_assign(&mut self, rhs: &LineColor) {
-        self.line_color = Some(rhs.value);
+        self.line_color = Some(rhs.clone());
     }
 }
 
